==> jc-1.4.0.tar.gz: javax/swing/SwingUtilities__241.h <==
// final class javax.swing.SwingUtilities$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6275be082782ce00 javax_swing_SwingUtilities__241

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_SwingUtilities__241_H_
#define _JC_javax_swing_SwingUtilities__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_SwingUtilities__241$sub_refs	_jc_javax_swing_SwingUtilities__241$sub_refs;
typedef struct _jc_javax_swing_SwingUtilities__241$sub_nonrefs	_jc_javax_swing_SwingUtilities__241$sub_nonrefs;
typedef struct _jc_javax_swing_SwingUtilities__241$refs	_jc_javax_swing_SwingUtilities__241$refs;
typedef struct _jc_javax_swing_SwingUtilities__241$nonrefs	_jc_javax_swing_SwingUtilities__241$nonrefs;
typedef struct _jc_javax_swing_SwingUtilities__241$object	_jc_javax_swing_SwingUtilities__241$object;

typedef const struct _jc_javax_swing_SwingUtilities__241$vmethods	_jc_javax_swing_SwingUtilities__241$vmethods;
typedef const struct _jc_javax_swing_SwingUtilities__241$vtable	_jc_javax_swing_SwingUtilities__241$vtable;
typedef const struct _jc_javax_swing_SwingUtilities__241$vtype	_jc_javax_swing_SwingUtilities__241$vtype;

// Constructors
extern void _jc_javax_swing_SwingUtilities__241$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_SwingUtilities__241$object *);

// Virtual methods structure
struct _jc_javax_swing_SwingUtilities__241$vmethods {
};

// Vtable
struct _jc_javax_swing_SwingUtilities__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_SwingUtilities__241$vmethods	javax_swing_SwingUtilities__241;
};

// Vtype
struct _jc_javax_swing_SwingUtilities__241$vtype {
	_jc_type			type;
	_jc_javax_swing_SwingUtilities__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_SwingUtilities__241$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_SwingUtilities__241$refs {
    _jc_javax_swing_SwingUtilities__241$sub_refs	javax_swing_SwingUtilities__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_SwingUtilities__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_SwingUtilities__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_SwingUtilities__241$sub_nonrefs	javax_swing_SwingUtilities__241;
};

// Object instance structure
struct _jc_javax_swing_SwingUtilities__241$object {
	_jc_javax_swing_SwingUtilities__241$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_SwingUtilities__241$vtype	*vtype;
	_jc_javax_swing_SwingUtilities__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_SwingUtilities__241$vtype _jc_javax_swing_SwingUtilities__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_SwingUtilities__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_SwingUtilities__241$class_object;

#endif	/* _JC_javax_swing_SwingUtilities__241_H_ */

==> jc-1.4.6.tar.gz: javax/swing/SwingUtilities__241.h <==
// final class javax.swing.SwingUtilities$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6275be082782ce00 javax_swing_SwingUtilities__241

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_SwingUtilities__241_H_
#define _JC_javax_swing_SwingUtilities__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_SwingUtilities__241$sub_refs	_jc_javax_swing_SwingUtilities__241$sub_refs;
typedef struct _jc_javax_swing_SwingUtilities__241$sub_nonrefs	_jc_javax_swing_SwingUtilities__241$sub_nonrefs;
typedef struct _jc_javax_swing_SwingUtilities__241$refs	_jc_javax_swing_SwingUtilities__241$refs;
typedef struct _jc_javax_swing_SwingUtilities__241$nonrefs	_jc_javax_swing_SwingUtilities__241$nonrefs;
typedef struct _jc_javax_swing_SwingUtilities__241$object	_jc_javax_swing_SwingUtilities__241$object;

typedef const struct _jc_javax_swing_SwingUtilities__241$vmethods	_jc_javax_swing_SwingUtilities__241$vmethods;
typedef const struct _jc_javax_swing_SwingUtilities__241$vtable	_jc_javax_swing_SwingUtilities__241$vtable;
typedef const struct _jc_javax_swing_SwingUtilities__241$vtype	_jc_javax_swing_SwingUtilities__241$vtype;

// Constructors
extern void _jc_javax_swing_SwingUtilities__241$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_SwingUtilities__241$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_SwingUtilities__241$vmethods {
};

// Vtable
struct _jc_javax_swing_SwingUtilities__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_SwingUtilities__241$vmethods	javax_swing_SwingUtilities__241;
};

// Vtype
struct _jc_javax_swing_SwingUtilities__241$vtype {
	_jc_type			type;
	_jc_javax_swing_SwingUtilities__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_SwingUtilities__241$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_SwingUtilities__241$refs {
    _jc_javax_swing_SwingUtilities__241$sub_refs	javax_swing_SwingUtilities__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_SwingUtilities__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_SwingUtilities__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_SwingUtilities__241$sub_nonrefs	javax_swing_SwingUtilities__241;
};

// Object instance structure
struct _jc_javax_swing_SwingUtilities__241$object {
	_jc_javax_swing_SwingUtilities__241$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_SwingUtilities__241$vtype	*vtype;
	_jc_javax_swing_SwingUtilities__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_SwingUtilities__241$vtype _jc_javax_swing_SwingUtilities__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_SwingUtilities__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_SwingUtilities__241$class_object;

#endif	/* _JC_javax_swing_SwingUtilities__241_H_ */
